AudioFocusManager class

Manages audio focus for the application

Constructors

AudioFocusManager(AudioSessionManager _sessionManager)
Creates a new audio focus manager

Properties

currentState → AudioFocusState
Gets the current audio focus state
no setter
hashCode → int
The hash code for this object.
no setterinherited
onAudioFocusChange ← AudioFocusChangeCallback?
Sets the callback to invoke when audio focus changes
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

abandonFocus() → Future<bool>
Abandons audio focus
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestFocus() → Future<bool>
Requests audio focus
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited