PlayerState class

Represents the combined state of the player

Constructors

PlayerState(ProcessingState processingState, bool playing)
Creates a new player state
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
playing → bool
Whether the player is playing
final
processingState → ProcessingState
The current processing state
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override