AudioSession class

Represents an audio session

Properties

becomingNoisyEventStream → Stream<void>
Stream of "becoming noisy" events
no setter
configuration → AudioSessionConfiguration?
Gets the current configuration
no setter
hashCode → int
The hash code for this object.
no setterinherited
interruptionEventStream → Stream<InterruptionEvent>
Stream of interruption events
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(AudioSessionConfiguration configuration) → Future<bool>
Configures the audio session
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setActive(bool active) → Future<bool>
Sets the audio session active or inactive
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

instance() → Future<AudioSession>
Gets the singleton instance