AudioSessionConfiguration class

Configuration for an audio session

Constructors

AudioSessionConfiguration({AudioUsage usage = AudioUsage.media, AudioContentType contentType = AudioContentType.music, bool canDuck = true, bool canPause = true, bool handleBecomingNoisy = true})
Creates a new audio session configuration
const
AudioSessionConfiguration.alarm()
Creates a configuration for alarm sounds
factory
AudioSessionConfiguration.call()
Creates a configuration for voice calls
factory
AudioSessionConfiguration.music()
Creates a configuration for music playback
factory
AudioSessionConfiguration.notification()
Creates a configuration for notification sounds
factory
AudioSessionConfiguration.speech()
Creates a configuration for speech playback
factory

Properties

canDuck → bool
Whether the session can duck (lower volume) when interrupted
final
canPause → bool
Whether the session can be paused when interrupted
final
contentType → AudioContentType
The audio content type
final
handleBecomingNoisy → bool
Whether the session should handle becoming noisy events
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usage → AudioUsage
The audio usage type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts this configuration to a map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited