AudioSessionConfiguration class

Configuration for the audio session

Constructors

AudioSessionConfiguration({AudioContentType contentType = AudioContentType.music, AudioFocusStrategy focusStrategy = AudioFocusStrategy.gainAndPauseOthers, bool pauseWhenDucked = false})
Creates a configuration for the audio session
AudioSessionConfiguration.music()
Creates a configuration suitable for music playback
factory
AudioSessionConfiguration.speech()
Creates a configuration suitable for speech playback
factory

Properties

contentType → AudioContentType
The type of audio content
final
focusStrategy → AudioFocusStrategy
The focus strategy
final
hashCode → int
The hash code for this object.
no setterinherited
pauseWhenDucked → bool
Whether to pause when ducked (for speech content)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the configuration to a map for platform channel
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited