AudioSessionManager class

Manages the audio session for the app

Constructors

AudioSessionManager()
Factory constructor to return the singleton instance
factory

Properties

becomingNoisyEventStream → Stream<void>
Stream of "becoming noisy" events
no setter
configuration → AudioSessionConfiguration?
Get the current configuration
no setter
hashCode → int
The hash code for this object.
no setterinherited
initialized → bool
Whether the manager has been initialized
no setter
interruptionEventStream → Stream<InterruptionEvent>
Stream of interruption events
no setter
isActive → bool
Get whether the session is active
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(AudioSessionConfiguration configuration) → Future<void>
Configure the audio session
initialize() → Future<void>
Initialize the audio session manager
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setActive(bool active) → Future<bool>
Activate the audio session
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited