InterruptionEvent class

Event representing an audio interruption

Constructors

InterruptionEvent({required bool begin, required InterruptionType type})
Creates an interruption event

Properties

begin → bool
Whether the interruption is beginning or ending
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → InterruptionType
The type of interruption
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited