FileAudioSource class

An audio source from a file

Inheritance

Constructors

FileAudioSource({required File file, String? title, String? artist, String? album, String? artUri, String? genre, int? trackNumber, int? trackCount, int? year})
Creates an audio source from a file

Properties

album → String?
The album of the audio source
finalinherited
artist → String?
The artist of the audio source
finalinherited
artUri → String?
The URI of the album art
finalinherited
file → File
The file
final
genre → String?
The genre of the audio source
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
The headers to use when making HTTP requests
finalinherited
id → String
The unique identifier for this audio source
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
The title of the audio source
finalinherited
trackCount → int?
The total number of tracks in the album
finalinherited
trackNumber → int?
The track number of the audio source
finalinherited
uri → Uri
The URI of the audio source
finalinherited
year → int?
The year of the audio source
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts this audio source to a map for platform channel
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited