UriAudioSource class

An audio source from a URI (remote URL, asset, or file)

Inheritance
Implementers

Constructors

UriAudioSource({required Uri uri, String? title, String? artist, String? album, String? artUri, String? genre, int? trackNumber, int? trackCount, int? year, Map<String, String>? headers})
Creates an audio source from a URI

Properties

album → String?
The album of the audio source
final
artist → String?
The artist of the audio source
final
artUri → String?
The URI of the album art
final
genre → String?
The genre of the audio source
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
The headers to use when making HTTP requests
final
id → String
The unique identifier for this audio source
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
The title of the audio source
final
trackCount → int?
The total number of tracks in the album
final
trackNumber → int?
The track number of the audio source
final
uri → Uri
The URI of the audio source
final
year → int?
The year of the audio source
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts this audio source to a map for platform channel
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited