flutter_audio_recorder_player library

Classes

AssetAudioSource
An audio source from an asset
AudioFocusManager
Manages audio focus for the application
AudioJoiner
A widget for joining multiple WAV audio files.
AudioPlayer
A more user-friendly API for the audio player, inspired by just_audio
AudioRecording
Represents a recorded audio file with metadata
AudioSession
Represents an audio session
AudioSessionConfiguration
Configuration for an audio session
AudioSource
Base class for all audio sources
AudioTrimmer
A widget for trimming WAV audio files.
ConcatenatingAudioSource
A concatenating audio source that plays multiple audio sources one after the other
FileAudioSource
An audio source from a file
FlutterAudioRecorderPlayer
A Flutter plugin for audio streaming, playback, and recording.
PcmData
A class that represents PCM audio data.
PlaybackState
Represents the current state of audio playback
PlayerState
Represents the combined state of the player
Playlist
Represents a playlist of audio sources
StreamSubscription<T>
A subscription on events from a Stream.
UriAudioSource
An audio source from a URI (remote URL, asset, or file)
UrlAudioSource
An audio source from a URL
VisualizationData
A class that represents audio visualization data.
WaveformView
A widget that displays a waveform visualization of a WAV file.
WavHeader
WAV file header information

Enums

AudioContentType
Audio content types
AudioFocusState
Represents the audio focus state
AudioUsage
Audio usage types
ProcessingState
Represents the current processing state of the player

Typedefs

AudioFocusChangeCallback = void Function(AudioFocusState state)
Callback for audio focus changes

Exceptions / Errors

PlayerException
Exception thrown by the audio player
SourceException
Exception thrown when loading an audio source fails