PcmData class

A class that represents PCM audio data.

Constructors

PcmData({required Uint8List pcmData, double rmsValue = 0.0, int timestamp = 0})
Creates a new PcmData instance.
PcmData.fromMap(Map map)
Creates a PcmData from a map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pcmData → Uint8List
Raw PCM data as bytes.
final
rmsValue → double
RMS (Root Mean Square) value of the PCM data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int
Timestamp when the PCM data was captured.
final

Methods

getNormalizedSamples() → List<double>
Gets the PCM samples normalized to values between -1.0 and 1.0.
getPeakAmplitude() → double
Gets the peak amplitude of the PCM data.
getRmsValue() → double
Gets the RMS (Root Mean Square) value of the PCM data.
getSamples16Bit() → List<int>
Gets the PCM samples as 16-bit integers.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited