PlayerException class

Exception thrown by the audio player

Implemented types
Implementers

Constructors

PlayerException(String code, String message, [dynamic details])
Creates a new player exception
PlayerException.fromMap(Map map)
Creates a player exception from a map
factory

Properties

code → String
The error code
final
details → dynamic
Additional error details
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
The error message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts this exception to a map
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited