VisualizationData class

A class that represents audio visualization data.

Constructors

VisualizationData({Uint8List? waveform, Uint8List? fft, int timestamp = 0})
Creates a new VisualizationData instance.
VisualizationData.fromMap(Map map)
Creates a VisualizationData from a map.
factory

Properties

fft → Uint8List?
Raw FFT (frequency) data as bytes.
final
hasFft → bool
Returns true if this visualization data has valid FFT data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasWaveform → bool
Returns true if this visualization data has valid waveform data.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int
Timestamp when the visualization data was captured.
final
waveform → Uint8List?
Raw waveform data as bytes.
final

Methods

getAmplitudeValues() → List<double>
Gets the amplitude values from the waveform data.
getFrequencyValues() → List<double>
Gets the frequency spectrum values from the FFT data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited